<?php
// Set-up Action and Filter Hooks
register_activation_hook(__FILE__, 'asl_add_defaults');
register_uninstall_hook(__FILE__, 'asl_delete_plugin_options');

// Delete options table entries ONLY when plugin deactivated AND deleted
function asl_delete_plugin_options() {
	delete_option('asl_plugin');
}

// Define default option settings
function asl_add_defaults() {
	$tmp = get_option('asl_plugin');
    if(!$tmp || !is_array($tmp)) {
		delete_option('adp_plugin');
		$arr = array(
						"thumb" => "1",
						"ssw" => "480",
						"iconsize" => "72",
						"current" => "0",
						"linkshareid" => "",
						"default_store" => "US"
		);
		update_option('asl_plugin', $arr);
	}
}


add_action('admin_init', 'asl_pluginoptions_init' );
add_action('admin_menu', 'asl_pluginoptions_add_page');

// Init plugin options to white list our options
function asl_pluginoptions_init(){
	$settings = get_option('asl_options');
	if(!$settings) asl_add_defaults();
	register_setting( 'asl_pluginoptions_options', 'asl_plugin', 'asl_pluginoptions_validate' );
}

// Add menu page
function asl_pluginoptions_add_page() {
	add_options_page('AppStore Lookup Options', 'AppStore Lookup', 'manage_options', 'asl_pluginoptions', 'asl_pluginoptions_do_page');
}

// Draw the menu page itself
function asl_pluginoptions_do_page() {
	?>
	<div class="wrap">
    	<?php screen_icon(); ?>
		<h2>AppStore Lookup Options</h2>
		<form action="options.php" method="post">
			<?php settings_fields('asl_pluginoptions_options'); ?>
			<?php $options = get_option('asl_plugin'); ?>
			<table class="form-table">
				<tr valign="top"><th scope="row">Use TimThumb:</th>
					<td><input name="asl_plugin[thumb]" type="checkbox" value="1" <?php checked('1', $options['thumb']); ?> /><br />
                    <span style="color:#666666;margin-left:2px;">This option allows you to use <a href="https://code.google.com/p/timthumb/" target="_blank">TimThumb</a> to dynamically resize images and store caches on your server, rather than using the full-size images from Apple and resizing via HTML or CSS.  This option can be overwritten in the shortcodes for individual cases.</span>
                    </td>
				</tr>
                <tr valign="top"><th scope="row">Default screenshot width:</th>
					<td><input type="text" name="asl_plugin[ssw]" value="<?php echo $options['ssw']; ?>" size="4" />px<br /? />
                    <span style="color:#666666;margin-left:2px;">Set the default image width.  Screenshot aspect ratio will always be maintained.</span>
                 </td>
				</tr> 
                <tr valign="top"><th scope="row">Default icon dimensions (square):</th>
					<td><input type="text" name="asl_plugin[iconsize]" value="<?php echo $options['iconsize']; ?>" size="3"/>px<br />
                    <span style="color:#666666;margin-left:2px;">Set the default icon width.  Aspect ratio will always be maintained.</span></td>
				</tr>
                <tr valign="top"><th scope="row">Default to Current version:</th>
					<td><input name="asl_plugin[current]" type="checkbox" value="1" <?php checked('1', $options['current']); ?> /><br />
                    <span style="color:#666666;margin-left:2px;">Display total and average rating for only the current version of the application.</span>
                    </td>
				</tr>
				<tr valign="top"><th scope="row">LinkShare ID:</th>
					<td><input type="text" name="asl_plugin[linkshareid]" value="<?php echo $options['linkshareid']; ?>" /><br />
                    <span style="color:#666666;margin-left:2px;">If you have a Linkshare ID, add it here to turn any download link into a Linkshare affiliate link.  If you don't have an ID, leave this blank.</span>
                    </td>
				</tr>
			</table>
			<p class="submit">
			<input type="submit" class="button-primary" value="<?php _e('Save Changes') ?>" />
			</p>
		</form>
	</div>
    
    <h3 style="margin-top:30px;">Shortcodes</h3>
    <p>These are the shortcodes you can use to display your app data.  An appstore id passed with the <code>id=</code> parameter is required for all shortcodes.</p>
    <p><strong>New:</strong> setting a post custom attribute called <code>appId</code> with the value of your AppStore ID will eliminate the requirement for setting an id in the shortcode.</p>
    <ul class="ul-disc">
    	<li><code>asl_name</code> Will display the name of the application.</li>
        <li><code>asl_icon</code> Will output the icon image.  Optional parameters: <code>thumb</code> <code>w</code>, <code>q</code></li>
        <li><code>asl_genre</code> Will display the Primary genre of the application.</li>
        <li><code>asl_price</code> Displays the formatted price of the application.</li>
        <li><code>asl_version</code> Displays the latest version number of the application.</li>
        <li><code>asl_description</code> Outputs the description using <a href="http://ca3.php.net/nl2br" target="_blank">nl2br</a>.</li>
        <li><code>asl_seller</code> Outputs the seller name.</li>
        <li><code>asl_filesize</code> Displays the filesize in B, KB, MB, GB, or TB (!) depending on the size.</li>
        <li><code>asl_release_notes</code> Displays the release notes for the current version using nl2br.</li>
        <li><code>asl_rating</code> Displays the Average User rating.  Optionally can display for only the current version using <code>current</code>.</li>
        <li><code>asl_num_ratings</code> Displays the total number of ratings the app has received in iTunes.  Optionally can display for only the current version using <code>current</code>.</li>
        <li><code>asl_release_date</code> Displays the release date in <code>F j, Y</code> format.  Optionally accepts <code>dateformat</code> and any PHP <a href="http://ca3.php.net/manual/en/function.date.php" target="_blank">date format</a>.</li>
        <li><code>asl_content_rating</code> Displays the content advisory rating for the app.</li>
        <li><code>asl_screenshots</code> Displays the application screenshots in an unordered list.  Optionally accepts: <code>thumb</code>, <code>w</code>, <code>q</code>, <code>type</code>, <code>first</code></li>
    </ul>
    
    
    <h3 style="margin-top:30px;">Parameters</h3>
    <p>Parameters for shortcodes.</p>
    <ul class="ul-disc">
    	<li><code>id</code> The app id is required for all shortcodes.  This can also be passed as a post custom attribute called <code>appId</code>.</li>
        <li><code>thumb</code> Optional.  Overrides the default TimThumb setting.  Accepts true/false; 1,0</li>
        <li><code>w</code> Optional.  Overrides the default Width setting for screenshots or icon.  Accepts a number in pixels.</li>
        <li><code>q</code> Optional.  Changes the compression settings for TimThumb.  Accepts a number between 0 and 100.</li>
        <li><code>current</code> Optional for rating and num_ratings, overrides the default "current version only".  Accepts true, false, 1,0</li>
        <li><code>first</code>  Optional for screenshots, will display only the first screenshot.  Defaults to all.  Accepts true, false, 1,0</li>
        <li><code>img</code>  Optional for link, allows you to display the buy link as an image you choose (ie, Available in the AppStore image)</li>
        <li><code>title</code>  Optional for link, allows you to change the buy link text to something other than "Download"</li>
    </ul>
    
	<?php	
}

// Sanitize and validate input. Accepts an array, return a sanitized array. 
function asl_pluginoptions_validate($input) {
	return $input;
}
